@@ -64,7 +64,7 @@ from typing import Dict
 
 import numpy as np
 
-from .callbacks import Callback
+from poutyne.framework.callbacks.callbacks import Callback
 
 
 class EarlyStopping(Callback):
