@@ -20,8 +20,8 @@ You should have received a copy of the GNU Lesser General Public License along w
 # pylint: disable=too-many-locals,too-many-lines
 
 from math import ceil
-from unittest import skipIf, main
-from unittest.mock import MagicMock, ANY
+from unittest import main, skipIf
+from unittest.mock import ANY, MagicMock, Mock, call
 
 import numpy as np
 import torch
@@ -31,23 +31,25 @@ from torch.nn.utils.rnn import PackedSequence
 from torch.utils.data import DataLoader, Dataset
 
 from poutyne import Model, TensorDataset
+from poutyne.framework.metrics.decomposable import DecomposableMetric
 from poutyne.framework.optimizers import all_optimizers_dict
+from tests.framework.model.base import ModelFittingTestCase
 from tests.framework.tools import (
-    some_data_tensor_generator,
+    SomeBatchMetric,
+    SomeConstantMetric,
     SomeDataGeneratorUsingStopIteration,
     SomeDataGeneratorWithLen,
-    SomeConstantMetric,
+    SomeMetric,
+    repeat_batch_metric,
+    repeat_batch_metric_value,
     some_batch_metric_1,
     some_batch_metric_2,
-    repeat_batch_metric,
+    some_constant_metric_value,
+    some_data_tensor_generator,
     some_metric_1_value,
     some_metric_2_value,
-    repeat_batch_metric_value,
-    some_constant_metric_value,
-    SomeMetric,
 )
 from tests.utils import populate_packed_sequence
-from .base import ModelFittingTestCase
 
 
 def some_ndarray_generator(batch_size):
@@ -132,7 +134,7 @@ class ModelTest(ModelFittingTestCase):
             'steps': ModelTest.steps_per_epoch,
             'valid_steps': ModelTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_fitting_without_valid_generator(self):
         train_generator = some_data_tensor_generator(ModelTest.batch_size)
@@ -283,7 +285,7 @@ class ModelTest(ModelFittingTestCase):
             'steps': ModelTest.steps_per_epoch,
             'valid_steps': ModelTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_fitting_with_data_loader(self):
         train_real_steps_per_epoch = 30
@@ -476,7 +478,8 @@ class ModelTest(ModelFittingTestCase):
         train_generator = SomeDataGeneratorUsingStopIteration(
             batch_size=ModelTest.batch_size, length=train_real_steps_per_epoch
         )
-        valid_generator = SomeDataGeneratorUsingStopIteration(batch_size=15, length=10)
+        valid_real_steps = 10
+        valid_generator = SomeDataGeneratorUsingStopIteration(batch_size=15, length=valid_real_steps)
         logs = self.model.fit_generator(
             train_generator,
             valid_generator,
@@ -486,7 +489,7 @@ class ModelTest(ModelFittingTestCase):
             callbacks=[self.mock_callback],
         )
         params = {'epochs': ModelTest.epochs, 'steps': None}
-        self._test_callbacks_train(params, logs, steps=train_real_steps_per_epoch)
+        self._test_callbacks_train(params, logs, steps=train_real_steps_per_epoch, valid_steps=valid_real_steps)
 
     def test_tensor_train_on_batch(self):
         x = torch.rand(ModelTest.batch_size, 1)
@@ -725,8 +728,10 @@ class ModelTest(ModelFittingTestCase):
         self.assertEqual(first_metric, some_metric_1_value)
 
     def test_metrics_integration(self):
+        mock_metric = Mock(SomeBatchMetric, wraps=SomeBatchMetric())
+        mock_loss_fn = Mock(DecomposableMetric, wraps=DecomposableMetric(F.mse_loss, "loss"))
         num_steps = 10
-        model = Model(self.pytorch_network, self.optimizer, self.loss_function, batch_metrics=[F.mse_loss])
+        model = Model(self.pytorch_network, self.optimizer, mock_loss_fn, batch_metrics=[F.mse_loss, mock_metric])
         train_generator = some_data_tensor_generator(ModelTest.batch_size)
         valid_generator = some_data_tensor_generator(ModelTest.batch_size)
         model.fit_generator(
@@ -737,28 +742,76 @@ class ModelTest(ModelFittingTestCase):
             validation_steps=ModelTest.steps_per_epoch,
             callbacks=[self.mock_callback],
         )
+        expected_calls = self._get_batch_metrics_expected_on_calls_when_training(
+            epochs=ModelTest.epochs, steps=ModelTest.steps_per_epoch, valid_steps=ModelTest.steps_per_epoch
+        )
+        self.assertEqual(len(mock_metric.mock_calls), len(expected_calls))
+        self.assertEqual(mock_metric.mock_calls, expected_calls)
+
+        self.assertEqual(len(mock_loss_fn.mock_calls), len(expected_calls))
+        self.assertEqual(mock_loss_fn.mock_calls, expected_calls)
+
         generator = some_data_tensor_generator(ModelTest.batch_size)
-        loss, mse = model.evaluate_generator(generator, steps=num_steps)
-        self.assertEqual(type(loss), float)
-        self.assertEqual(type(mse), float)
+        loss, (mse, _) = model.evaluate_generator(generator, steps=num_steps)
+        self.assertIsInstance(loss, float)
+        self.assertIsInstance(mse, float)
 
     def test_epoch_metrics_integration(self):
-        model = Model(self.pytorch_network, self.optimizer, self.loss_function, epoch_metrics=[SomeMetric()])
+        some_metric = SomeMetric()
+        some_metric.__name__ = "mock_metric"
+        mock_metric = Mock(SomeBatchMetric, wraps=some_metric)
+        model = Model(
+            self.pytorch_network, self.optimizer, self.loss_function, epoch_metrics=[SomeMetric(), mock_metric]
+        )
         train_generator = some_data_tensor_generator(ModelTest.batch_size)
         valid_generator = some_data_tensor_generator(ModelTest.batch_size)
         logs = model.fit_generator(
             train_generator,
             valid_generator,
-            epochs=1,
+            epochs=ModelTest.epochs,
             steps_per_epoch=ModelTest.steps_per_epoch,
             validation_steps=ModelTest.steps_per_epoch,
         )
         actual_value = logs[-1]['some_metric']
         val_actual_value = logs[-1]['val_some_metric']
-        expected_value = 5
+        expected_value = ModelTest.steps_per_epoch
         self.assertEqual(val_actual_value, expected_value)
         self.assertEqual(actual_value, expected_value)
 
+        expected_calls = self._get_epoch_metrics_expected_on_calls_when_training(
+            epochs=ModelTest.epochs, steps=ModelTest.steps_per_epoch, valid_steps=ModelTest.steps_per_epoch
+        )
+        self.assertEqual(len(mock_metric.mock_calls), len(expected_calls))
+        self.assertEqual(mock_metric.mock_calls, expected_calls)
+
+    def _get_batch_metrics_expected_on_calls_when_training(self, epochs, steps, has_valid=True, valid_steps=None):
+        call_list = []
+        for _ in range(epochs):
+            for _ in range(steps):
+                call_list.append(call(ANY, ANY))
+            call_list.append(call.compute())
+            call_list.append(call.reset())
+            if has_valid:
+                for _ in range(1, valid_steps + 1):
+                    call_list.append(call(ANY, ANY))
+                call_list.append(call.compute())
+                call_list.append(call.reset())
+        return call_list
+
+    def _get_epoch_metrics_expected_on_calls_when_training(self, epochs, steps, has_valid=True, valid_steps=None):
+        call_list = []
+        for _ in range(epochs):
+            for _ in range(steps):
+                call_list.append(call.update(ANY, ANY))
+            call_list.append(call.compute())
+            call_list.append(call.reset())
+            if has_valid:
+                for _ in range(1, valid_steps + 1):
+                    call_list.append(call.update(ANY, ANY))
+                call_list.append(call.compute())
+                call_list.append(call.reset())
+        return call_list
+
     def test_evaluate_with_no_metric(self):
         model = Model(self.pytorch_network, self.optimizer, self.loss_function)
         x = torch.rand(ModelTest.evaluate_dataset_len, 1)
@@ -1136,7 +1189,7 @@ class ModelDatasetMethodsTest(ModelFittingTestCase):
             'steps': ModelTest.steps_per_epoch,
             'valid_steps': ModelTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_fitting_mnist_without_valid(self):
         logs = self.model.fit_dataset(
