@@ -23,8 +23,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 
 from poutyne import Model
-
-from .base import ModelFittingTestCase
+from tests.framework.model.base import ModelFittingTestCase
 
 
 class DictIOModel(nn.Module):
@@ -92,7 +91,7 @@ class ModelMultiDictIOTest(ModelFittingTestCase):
             'steps': ModelMultiDictIOTest.steps_per_epoch,
             'valid_steps': ModelMultiDictIOTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelMultiDictIOTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_tensor_train_on_batch_multi_dict_io(self):
         x, y = get_batch(ModelMultiDictIOTest.batch_size)
