@@ -23,8 +23,7 @@ import torch.nn as nn
 from torch.utils.data import DataLoader
 
 from poutyne import Model, TensorDataset
-
-from .base import ModelFittingTestCase, MultiIOModel
+from tests.framework.model.base import ModelFittingTestCase, MultiIOModel
 
 
 def some_data_tensor_generator_multi_input(batch_size):
@@ -67,7 +66,7 @@ class ModelMultiInputTest(ModelFittingTestCase):
             'steps': ModelMultiInputTest.steps_per_epoch,
             'valid_steps': ModelMultiInputTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelMultiInputTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_fitting_with_tensor_multi_input(self):
         train_real_steps_per_epoch = 30
