@@ -23,8 +23,7 @@ import torch.nn as nn
 from torch.utils.data import DataLoader
 
 from poutyne import Model, TensorDataset
-
-from .base import ModelFittingTestCase, MultiIOModel
+from tests.framework.model.base import ModelFittingTestCase, MultiIOModel
 
 
 def some_data_tensor_generator_multi_output(batch_size):
@@ -76,7 +75,7 @@ class ModelMultiOutputTest(ModelFittingTestCase):
             'steps': ModelMultiOutputTest.steps_per_epoch,
             'valid_steps': ModelMultiOutputTest.steps_per_epoch,
         }
-        self._test_callbacks_train(params, logs, valid_steps=ModelMultiOutputTest.steps_per_epoch)
+        self._test_callbacks_train(params, logs)
 
     def test_fitting_with_tensor_multi_output(self):
         train_real_steps_per_epoch = 30
